@@ -298,16 +298,23 @@ class ESWrapper:
     def ilm_explain(self, api_response):
         """Loop through the index response and look for ERROR steps. Return 1 is any ERRORS found"""
         for index in api_response["indices"].keys():
-           if api_response["indices"][index]["managed"] == "true":
-               if api_response["indices"][index]["step"] == "ERROR":
-                   res = 1
-               else:
-                   res = 0
+            print(index)
+            if api_response["indices"][index]["managed"] == "true":
+                print("true")
+                if api_response["indices"][index]["step"] == "ERROR":
+                    print("error")
+                    res = 1
+                    return res
+                else:
+                    print("no error")
+                    res = 0
+                    return res
 
     def send_requests(self, args):
         """GET METRICS"""
 
         api_call = getattr(self.es_config, args.api)
+        print(api_call)
 
         if args.parameters:
             api_parameters = dict(
@@ -321,6 +328,7 @@ class ESWrapper:
 
         try:
             api_response = getattr(api_call, args.endpoint)(**api_parameters)
+            print(api_response)
         # Elasticsearch serialization error
         except exceptions.SerializationError:
             logging.error("SerializationError. "
@@ -352,8 +360,10 @@ class ESWrapper:
                                   "Likley cause: '--nodes' has not been specified. Terminating")
                     sys.exit(1)
             elif args.metric == "ilm_explain":
+                print("ilm_explain == true")
                 try:
                     response = self.ilm_explain(api_response)
+                    print(response)
                     return response
                 except:
                     logging.error("ILM Explain Error")
